@@ -825,12 +825,12 @@ dbus_binding_tool_output_glib_server (BaseInfo *info, GIOChannel *channel, const
   if (error && *error != NULL)
     {
       ret = FALSE;
-      g_io_channel_close (data.channel);
+      g_io_channel_shutdown (data.channel, TRUE, error);
       g_io_channel_unref (data.channel);
       goto io_lose;
     }
 
-  g_io_channel_close (data.channel);
+  g_io_channel_shutdown (data.channel, TRUE, error);
   g_io_channel_unref (data.channel);
   
   /* Now spawn glib-genmarshal to insert all our required marshallers */
@@ -838,6 +838,7 @@ dbus_binding_tool_output_glib_server (BaseInfo *info, GIOChannel *channel, const
   g_ptr_array_add (argv, "glib-genmarshal");
   g_ptr_array_add (argv, "--header");
   g_ptr_array_add (argv, "--body");
+  g_ptr_array_add (argv, "--skip-source");
   g_ptr_array_add (argv, g_strdup_printf ("--prefix=%s%s", MARSHAL_PREFIX, prefix));
   g_ptr_array_add (argv, tempfile_name);
   g_ptr_array_add (argv, NULL);
@@ -866,7 +867,7 @@ dbus_binding_tool_output_glib_server (BaseInfo *info, GIOChannel *channel, const
   if (iostatus != G_IO_STATUS_EOF)
     goto io_lose;
 
-  g_io_channel_close (genmarshal_stdout);
+  g_io_channel_shutdown (genmarshal_stdout, TRUE, error);
 
   WRITE_OR_LOSE ("#include <dbus/dbus-glib.h>\n");
 
@@ -1201,7 +1202,7 @@ write_formal_declarations_for_direction (InterfaceInfo *iface, MethodInfo *metho
      {
        ArgInfo *arg;
       GType gtype;
-      const char *type_str, *type_suffix;
+      const char *type_str, *type_suffix, *type_initializer = "";
       int dir;
 
        arg = args->data;
@@ -1229,7 +1230,10 @@ write_formal_declarations_for_direction (InterfaceInfo *iface, MethodInfo *metho
 	  if (direction == ARG_IN)
 	    type_suffix = "*";
 	  else
-	    type_suffix = "";
+	    {
+	      type_suffix = "";
+	      type_initializer = " = { 0, }";
+	    }
 	}
       else if ((g_type_is_a (gtype, G_TYPE_BOXED)
 	      || g_type_is_a (gtype, G_TYPE_OBJECT)
@@ -1250,9 +1254,10 @@ write_formal_declarations_for_direction (InterfaceInfo *iface, MethodInfo *metho
            goto io_lose;
          break;
        case ARG_OUT:
-         if (!write_printf_to_iochannel ("  %s%s OUT_%s;\n", channel, error,
+         if (!write_printf_to_iochannel ("  %s%s OUT_%s%s;\n", channel, error,
                                          type_str, type_suffix,
-                                         arg_info_get_name (arg)))
+                                         arg_info_get_name (arg),
+                                         type_initializer))
            goto io_lose;
          break;
        case ARG_INVALID:
