@@ -160,6 +160,8 @@ void       dbus_g_error_domain_register        (GQuark                domain,
 void       dbus_g_connection_register_g_object (DBusGConnection       *connection,
 						const char            *at_path,
 						GObject               *object);
+void       dbus_g_connection_unregister_g_object (DBusGConnection *connection,
+                                                  GObject *object);
 GObject *  dbus_g_connection_lookup_g_object   (DBusGConnection       *connection,
 						const char            *at_path);
 
@@ -308,7 +310,7 @@ typedef struct _DBusGMethodInvocation DBusGMethodInvocation;
 
 void              dbus_g_method_return               (DBusGMethodInvocation *context, ...);
 
-void              dbus_g_method_return_error         (DBusGMethodInvocation *context, GError *error);
+void              dbus_g_method_return_error         (DBusGMethodInvocation *context, const GError *error);
 
 /* Probably possible to replace this with a closure */
 typedef struct {
